{ nix-flatpak, lib, pkgs, ... }:
{
  nixpkgs.config.allowUnfree = true;
  home = {
    packages = with pkgs; [
      gnupg
      eza
      just
      fd
      fzf
      bat
      jq
      yt-dlp
      htop
      ripgrep
      erdtree
      age
      figlet
      ffmpeg
      
      usbutils
      pciutils
      util-linux
      coreutils
      libgcc
      raylib
      SDL2
      protonplus

      ruby
      janet
      jpm
      python3
      sbcl
      nodejs_18
      platformio-core

      borgmatic
      kanata-with-cmd
      wezterm 
      emacs
      fish
      starship
      lazygit
      nnn
      isync
      msmtp
      jetbrains-mono

      bitwarden-cli
      bitwarden-desktop
      tailscale
      protonplus
      gnomeExtensions.just-perfection
      gnomeExtensions.dash-to-dock
      gnomeExtensions.pano
      gnome-software
      gnome-tweaks
      colloid-gtk-theme
      colloid-icon-theme
      #turtle
      papers
      newsflash
      helvum
      
      librewolf
      ungoogled-chromium
      albert
      obsidian
      vlc
      polychromatic
      discord
      slack
      signal-desktop
      libreoffice
      plexamp
      audacity
      supercollider-with-plugins
      bitwig-studio
      blender
      davinci-resolve-studio
      steam
      zotero_7
    ];

    username = "emenel";
    homeDirectory = "/home/emenel";

    stateVersion = "24.05";
  };
  
  programs = {
    home-manager.enable = true;
    direnv = {
      enable = true;
      #enableFishIntegration = true; # see note on other shells below
      nix-direnv.enable = true;
    };
    fish.enable = true;
    starship = {
      enable = true;
      enableFishIntegration = true;
    };
  };

  services = {
    flatpak.enable = true;
    #tailscale.enable = true;
  };

  xdg.systemDirs.data = [
    "/home/emenel/.local/share/applications/wine/Programs"
    "/home/emenel/.local/share/applications"
    "/var/lib/flatpak/exports/share"
    "/home/emenel/.local/share/flatpak/exports/share"
    "/home/emenel/.nix-profile/share/applications"
  ];

  services.flatpak.packages = [
    "io.github.zen_browser.zen"
    "com.github.johnfactotum.QuickLookup"
  ];

  xdg.configFile."starship.toml".source = ../dotfiles/dot_config/starship.toml;
  xdg.configFile."wezterm".source = ../dotfiles/dot_config/wezterm;

  xdg.configFile."fish/functions" = {
    source = ../dotfiles/dot_config/fish/functions;
    recursive = true;
  };

  xdg.configFile."emacs".enable = false;

#  xdg.dataFile."share/flf".source = ../dotfiles/dot_local/flf;


  #xdg.configFile."fish/functions/ll.fish".source = ../dotfiles/dot_config/fish/functions/ll.fish;
  #xdg.configFile."fish/functions/la.fish".source = ../dotfiles/dot_config/fish/functions/la.fish;
  #xdg.configFile."fish/functions/lg.fish".source = ../dotfiles/dot_config/fish/functions/lg.fish;
  xdg.configFile."fish/functions/ls.fish".source = ../dotfiles/dot_config/fish/functions/ls.fish;
  #xdg.configFile."fish/functions/sbcl.fish".source = ../dotfiles/dot_config/fish/functions/sbcl.fish;
  #xdg.configFile."fish/functions/pullall.fish".source = ../dotfiles/dot_config/fish/functions/pullall.fish;

}
